@@ -20,7 +20,8 @@
  */
 
 #include "config.h"
-#include <gnome.h>
+
+#include <glib/gi18n.h>
 
 #include "seahorse-unknown-key.h"
 #include "seahorse-unknown-source.h"
@@ -54,16 +55,18 @@ static GObject*
 seahorse_unknown_key_constructor (GType type, guint n_props, GObjectConstructParam* props)
 {
     SeahorseKey *skey;
+    SeahorseObject *sobj;
     GObject *obj;
     
     obj = G_OBJECT_CLASS (seahorse_unknown_key_parent_class)->constructor (type, n_props, props);
     skey = SEAHORSE_KEY (obj);
+    sobj = SEAHORSE_OBJECT (obj);
     
-    if (skey->sksrc)
-        skey->ktype = seahorse_key_source_get_ktype (skey->sksrc);
-    skey->location = SKEY_LOC_UNKNOWN;
+    if (seahorse_object_get_source (sobj))
+        sobj->_tag = seahorse_source_get_ktype (seahorse_object_get_source (sobj));
+    sobj->_location = SEAHORSE_LOCATION_MISSING;
     skey->loaded = SKEY_INFO_NONE;
-    skey->etype = SKEY_ETYPE_NONE;
+    sobj->_usage = SEAHORSE_USAGE_NONE;
     skey->keydesc = _("Unavailable");
     return obj;
 }
@@ -109,7 +112,7 @@ seahorse_unknown_key_get_property (GObject *object, guint prop_id,
     
     switch (prop_id) {
     case PROP_DISPLAY_NAME:
-        g_value_set_string_take_ownership (value, 
+        g_value_take_string (value, 
                 seahorse_unknown_key_get_name (SEAHORSE_KEY (ukey), 0));
         break;
     case PROP_DISPLAY_ID:
@@ -131,8 +134,7 @@ seahorse_unknown_key_get_property (GObject *object, guint prop_id,
         g_value_set_ulong (value, 0);
         break;
     case PROP_STOCK_ID:
-        /* We use a pointer so we don't copy the string every time */
-        g_value_set_pointer (value, "");
+        g_value_set_string (value, "");
         break;
     }
 }
@@ -141,14 +143,14 @@ static void
 seahorse_unknown_key_set_property (GObject *object, guint prop_id, 
                                    const GValue *value, GParamSpec *pspec)
 {
-    SeahorseUnknownKey *ukey = SEAHORSE_UNKNOWN_KEY (object);
+	SeahorseUnknownKey *ukey = SEAHORSE_UNKNOWN_KEY (object);
 
-    switch (prop_id) {
-    case PROP_KEYID:
-        ukey->keyid = g_value_get_uint (value);
-        SEAHORSE_KEY (ukey)->keyid = ukey->keyid;
-        break;
-    }
+	switch (prop_id) {
+	case PROP_KEYID:
+		ukey->keyid = g_value_get_uint (value);
+		SEAHORSE_OBJECT (ukey)->_id = ukey->keyid;
+		break;
+	}
 }
 
 static void
@@ -208,8 +210,8 @@ seahorse_unknown_key_class_init (SeahorseUnknownKeyClass *klass)
                            0, G_MAXULONG, 0, G_PARAM_READABLE));
                            
     g_object_class_install_property (gobject_class, PROP_STOCK_ID,
-        g_param_spec_pointer ("stock-id", "The stock icon", "The stock icon id",
-                              G_PARAM_READABLE));
+        g_param_spec_string ("stock-id", "The stock icon", "The stock icon id",
+                             "", G_PARAM_READABLE));
 
 }
 
@@ -224,9 +226,5 @@ seahorse_unknown_key_new (SeahorseUnknownSource *sksrc, GQuark keyid)
     
     ukey = g_object_new (SEAHORSE_TYPE_UNKNOWN_KEY, "key-source", sksrc, 
                          "key-id", keyid, NULL);
-    
-    /* We don't care about this floating business */
-    g_object_ref (GTK_OBJECT (ukey));
-    gtk_object_sink (GTK_OBJECT (ukey));
     return ukey;
 }
